#
# spec file for package kubefirst
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubefirst
Version:        2.3.5
Release:        1.1
Summary:        CLI for the KubeFirst GitOps Infrastructure & Application Delivery Platform
License:        MIT
URL:            https://github.com/kubefirst/kubefirst
Source:         kubefirst-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.18

%description
The Kubefirst CLI creates instant GitOps platforms that integrate some of the best tools in cloud native from scratch in minutes.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/kubefirst/runtime/configs.K1Version=v%{version}" \
   -o bin/kubefirst

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Thu Nov  2 2023 kastl@b1-systems.de
- Update to version 2.3.5:
  * chore: bump version (#1890)
* Wed Nov  1 2023 kastl@b1-systems.de
- Update to version 2.3.4:
  * fix: 1879 - launch up can depend on api default for
    isClusterZero (#1880)
  * chore: add a field for the OS for bug reports (#1882)
  * chore: add an installation option for Civo Marketplace in bug
    report (#1881)
  * chore: remove other installation instructions as moved to the
    docs (#1873)
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 2.3.3:
  * feat: 2.3.3 adopt latest gitops-template (#1871)
  * fix: cloudflare token, error handling for cluster creation
    (#1870)
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 2.3.2:
  * fix: styles json (#1868)
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 2.3.1:
  * pin cli to 2.3.1 (#1867)
  * chore: remove previous E2E tests (#1860)
* Tue Oct 24 2023 kastl@b1-systems.de
- Update to version 2.3.0:
  * 2.3.0 adoption (#1866)
  * 2.3.1 adoption in cli (#1865)
  * feat: adopt rc56 (#1864)
  * chore: remove prerun so we can support non-docker environments
    (#1863)
  * rc55 plus improved launch up env vars (#1862)
  * fix: error handling (#1859)
  * docs: fix Linux installation for other architecture than amd
    (#1856)
  * docs(README.md): fix asdf config (#1844)
  * docs: add beta clouds (#1858)
  * fix docs link in the readme (#1848)
  * fix: debug validation (#1854)
  * fixes bad error ref (#1855)
  * fix refernced metrics (#1853)
  * fix: adopt latest segment implementation in kubefirst (#1852)
  * feat k3d (#1846)
  * adopt rc42 in kubefirst launch (#1843)
  * adjustments needed for launch up to install latest macro
    (#1841)
  * core: add DNS information to bugs issue template (#1834)
  * feat: cli refactor (#1832)
  * ci: upgrade the DavidAnson/markdownlint-cli2-action action
    (#1828)
  * ci: add a Markdown link checker action (#1818)
  * ci: don't include PR number is commit linting lenght for titles
    (#1822)
  * ci: update config for markdown check for deprecated setting
    (#1821)
  * feat: civo create using launch up (#1820)
  * docs: add info on running kubefirst CLI with the latest
    gitops-template (#1819)
  * ci: add a workflow to validate Markdown syntax (#1817)
  * add a SECURITY.md file for security issues (close #883) (#1814)
  * fix: runtime version fixes detokenization
  * fix: aws containerRegistryURL metaphor duplication (#1797)
  * ci: add a workflow to check if the commits are signed (#1803)
  * chore: update launch version rc15 (#1800)
  * chore: update launch version (#1799)
  * runtime adjustment (#1798)
  * fix: fix the type of v1alpha1ArgocdApplication (#1796)
  * Api convention (#1795)
  * fix: changing to API convention from runtime (#1794)
  * cloudflare origin issuer adjustment (#1792)
  * fix: restructure flag caps
  * fix: enforce lowercase
* Tue Oct 10 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubefirst: CLI for the KubeFirst GitOps
  Infrastructure & Application Delivery Platform
